@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2016 Joao Ramos
+//  * Copyright (C) 1999-2022 Joao Ramos
  * Your use of this code is subject to the terms and conditions of the
  * GNU general public license version 2. See "COPYING" or
  * http://www.gnu.org/licenses/gpl.html
@@ -1360,6 +1360,38 @@ void ProcessOutputFile(char *OutputFile, int mem)
 			/*Step lkk1/2*/
 			if (!strcmp(lkk1, measure[k].search) || !strcmp(lkk2, measure[k].search)) {
 				measure_p_line[k] = measure[k].line; /*data to read has been found at measure[k].line from the current line of text!*/
+			#ifdef ASCO
+			#ifdef DEBUG
+			/*
+			 * For the situations where the output is changing, this code will at least warn about it
+			 */
+			} else {
+				switch(spice) {
+					case 1: /*Eldo*/
+					case 2: /*HSPICE*/
+					case 3: /*LTspice*/
+					case 4: /*Spectre*/
+						if (k>0) {
+							strcpy(lkk2, measure[k].search);
+							StripSpaces(lkk2);
+							if (strpos2(lkk2, " ", 1)) {
+								lkk2[strpos2(lkk2, " ", 1)-1]='\0';
+							}
+							if (strpos2(lkk, lkk2, 1)) {
+								printf("INFO: auxfunc_measurefromlis.c - ProcessOutputFile -- Measurement '%s' possibly found but with format different than the expected. Double check!\n", lkk2);
+							}
+						}
+						break;
+					case 50: /*Qucs*/
+					case 51: /*ngspice*/
+					case 100: /*general*/
+						break;
+					default:
+						printf("auxfunc_measurefromlis.c - ProcessOutputFile -- Something unexpected has happened!\n");
+						exit(EXIT_FAILURE);
+				}
+			#endif
+			#endif
 			}
 		}
 		/*1*/
