@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Joao Ramos
+ * Copyright (C) 2004-2022 Joao Ramos
  * Your use of this code is subject to the terms and conditions of the
  * GNU general public license version 2. See "COPYING" or
  * http://www.gnu.org/licenses/gpl.html
@@ -214,7 +214,7 @@ void LogtoFile(double cost)
 			sprintf(laux, "%s.log.log", hostname);  /*hostname is "longmorn"*/
 			break;
 		case 4: /*Spectre*/
-			sprintf(laux, "%s.log", hostname);      /*hostname is "longmorn"*/
+			sprintf(laux, "%s.log.log", hostname);      /*hostname is "longmorn"*/
 			break;
 		case 50: /*Qucs*/
 			sprintf(laux, "%s.log", hostname);      /*hostname is "longmorn"*/
@@ -373,7 +373,7 @@ void WriteToMem(int num_measures)
 			measurements[j].measured_value=asc2real(laux, 1, (int)strlen(laux)); /*4- convert it to double                                           */
 
 			if (!fcmp(measurements[j].measured_value, 0)) {                      /*5- check NaN and other text strings                               */
-				if ((laux[0] < 43) || (laux[0] > 57) ) /*if its text*/
+				if ((laux[0] < 43) || (laux[0] > 57) ) { /*if it is text*/
 					if (measurements[j].objective_constraint == 1) /*1=MIN*/
 						measurements[j].measured_value=+1e+30; /*so that a large cost is later assigned*/
 					if (measurements[j].objective_constraint == 2) /*2=MAX*/
@@ -382,6 +382,7 @@ void WriteToMem(int num_measures)
 						measurements[j].measured_value=+1e+30; /*so that a large cost is later assigned*/
 					if (measurements[j].objective_constraint > 4)  /*5=GE, 6=EQ*/
 						measurements[j].measured_value=-1e+30; /*so that a large cost is later assigned*/
+				}
 			}
 		}
 		i++;
@@ -432,16 +433,17 @@ double errfunc(char *filename, double *x)
 	/*Step1: scale input parameters from [-10, +10] to fit within desired range values*/
 	#ifdef DEBUG
 	printf("DEBUG: errfunc.c - Step1\n");
-	#endif
+	#else
 	for (i = 0; i < MAXPARAMETERS; i++) {
 		if (parameters[i].format) {
 			parameters[i].value = scaleto(x[i], -10, +10, parameters[i].minimum, parameters[i].maximum, parameters[i].format);
-			if (parameters[i].value<0) {
-				ii=1;
-				/*printf("INFO:  errfunc.c - Step1 -- Negative values\n");*/
-			}
+//			if (parameters[i].value<0) {
+//				ii=1;
+//				/*printf("INFO:  errfunc.c - Step1 -- Negative values\n");*/
+//			}
 		}
 	}
+	#endif
 
 
 	/**/
@@ -637,7 +639,7 @@ double errfunc(char *filename, double *x)
 			#ifndef __MINGW32__
 			sprintf(lkk, "nice -n 19 ./general.sh %s %s", hostname, hostname);
 			#else
-			sprintf(lkk, "./general.sh %s %s", hostname, hostname);
+			sprintf(lkk, ".\\general.bat %s %s", hostname, hostname);
 			#endif
 			break;
 		default:
