@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Joao Ramos
+ * Copyright (C) 2004-2022 Joao Ramos
  * Your use of this code is subject to the terms and conditions of the
  * GNU general public license version 2. See "COPYING" or
  * http://www.gnu.org/licenses/gpl.html
@@ -66,11 +66,11 @@ double evaluate(int D, double x[], char *filename)
 
 	/**/
 	/*Step3: In DEBUG mode, use initial values from the <inputfile>.cfg file*/
-	#ifdef DEBUG
-	for (ii = 0; ii < D; ii++) {
-		x[ii] = scaleto(parameters[ii].value, parameters[ii].minimum, parameters[ii].maximum, -10, +10, parameters[ii].format);
-	}
-	#endif
+//	#ifdef DEBUG
+//	for (ii = 0; ii < D; ii++) {
+//		x[ii] = scaleto(parameters[ii].value, parameters[ii].minimum, parameters[ii].maximum, -10, +10, parameters[ii].format);
+//	}
+//	#endif
 
 
 	/**/
