@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2016 Joao Ramos
+ * Copyright (C) 2004-2022 Joao Ramos
  * Your use of this code is subject to the terms and conditions of the
  * GNU general public license version 2. See "COPYING" or
  * http://www.gnu.org/licenses/gpl.html
@@ -149,22 +149,26 @@ double scaleto(double value, double ina, double inb, double outa, double outb, i
 			exit(EXIT_FAILURE);
 	}
 
+	#ifndef DEBUG
 	if (result < outa) {
-		#ifdef DEBUG
-		printf("INFO:  initialize.c - scaleto -- Initial value in *.cfg is lower than the minimum value. Double check!\n");
-		#else
-		printf("initialize.c - scaleto -- Initial value in *.cfg is lower than the minimum value\n");
+//		#ifdef DEBUG
+//		printf("INFO:  initialize.c - scaleto -- Initial value in *.cfg is lower than the minimum value. Double check!\n");
+//		#else
+//		printf("initialize.c - scaleto -- Initial value in *.cfg is lower than the minimum value\n");
+		printf("initialize.c - scaleto -- 'result' is is lower than the minimum value\n"); /*if it fails, something unexpected has happened*/
 		exit(EXIT_FAILURE);
-		#endif
+//		#endif
 	}
 	if (result > outb) {
-		#ifdef DEBUG
-		printf("INFO:  initialize.c - scaleto -- Initial value in *.cfg is larger than the maximum value. Double check!\n");
-		#else
-		printf("initialize.c - scaleto -- Initial value in *.cfg is larger than the maximum value\n");
+//		#ifdef DEBUG
+//		printf("INFO:  initialize.c - scaleto -- Initial value in *.cfg is larger than the maximum value. Double check!\n");
+//		#else
+//		printf("initialize.c - scaleto -- Initial value in *.cfg is larger than the maximum value\n");
+		printf("initialize.c - scaleto -- 'result' is larger than the maximum value\n"); /*if it fails, something unexpected has happened*/
 		exit(EXIT_FAILURE);
-		#endif
+//		#endif
 	}
+	#endif
 
 	return(result);
 }
@@ -209,17 +213,26 @@ void ReplaceSymbol(char *ret, int optimize)
 
 		if (optimize==0) { /*optimize=0 : we are initializing*/
 			if (parameters[i].optimize==0)
-				sprintf(laux, "%E", parameters[i].value);   /*writes the value*/
+				if ((parameters[i].format % 2)==0) {
+					sprintf(laux, "%d", (int)parameters[i].value); /*writes the value as integer*/
+				} else {
+					sprintf(laux, "%E", parameters[i].value);      /*writes the value*/
+				}
 			else
 				sprintf(laux, "#%s#",parameters[i].symbol); /*writes the #<symbol>#  back again*/
 		} else {           /*optimize=1 : we are optimizing*/
-			sprintf(laux, "%E", parameters[i].value);           /*writes the value*/
+			if ((parameters[i].format % 2)==0) {
+				sprintf(laux, "%d", (int)parameters[i].value); /*writes the value as integer*/
+			} else {
+				sprintf(laux, "%E", parameters[i].value);           /*writes the value*/
+			}
 		}
 
 InsertString(ret, laux, (ii-(int)strlen(parameters[i].symbol)-1), ii+1);
 
 //		strcat(ret, lxp);
 //		strcat(ret, laux);
+		ii=ii - ( (int)strlen(parameters[i].symbol) - ((int)strlen(laux) - 2) ); //to account for size difference if a 'symbol' is replaced (optimize=1) by its numerical value, and 'symbol' initially has a larger string size than its numerical value size (in string format)
 		ii++; /*because 'ReadSubKey' starts at [ii-1] instead of [ii]*/
 		ReadSubKey(laux, ret, &ii, '#', '#', 0);
 	}
@@ -400,6 +413,15 @@ int initialize(char *filename) /* , double *x) */
 					exit(EXIT_FAILURE);
 				}
 
+				#ifdef DEBUG
+				if (parameters[i].value < parameters[i].minimum) {
+					printf("INFO:  initialize.c - Step2 -- Initial value in *.cfg is less than the minimum value. Double check!\n");
+				}
+				if (parameters[i].value > parameters[i].maximum) {
+					printf("INFO:  initialize.c - Step2 -- Initial value in *.cfg is greater than the maximum value. Double check!\n");
+				}
+				#endif
+
 				ReadSubKey(laux, lkk, &ii, ':', ':', 5);                    /*format  */
 				if (laux[0] == 'E') {
 					char IEC60063[] = " 3 6 12 24 48 96 192 ";
